@@ -1,15 +1,3 @@
-#
-# This file is part of MouseX-App-Cmd
-#
-# This software is copyright (c) 2011 by Infinity Interactive.
-#
-# This is free software; you can redistribute it and/or modify it under
-# the same terms as the Perl 5 programming language system itself.
-#
-use 5.006;
-use strict;
-use warnings;
-
 package Test::ConfigFromFile::Command::moo;
 use Mouse;
 use YAML();
